# Copyright (c) 2007 Canonical
#
# Written by Jamshed Kakar <jkakar@kakar.ca>
#
# This file is part of AutoPPA.
#
# AutoPPA is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation; either version 2.1 of the
# License, or (at your option) any later version.
#
# AutoPPA is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import re
import os


def match_path_if(root_path, regexp):
    """Search from C{root_path} and yield filenames that match C{regexp}.

    Hidden directories are ignored.

    @param root_path: The root path to search from.
    @param regexp: A string containing a regular expression to match
        filenames against.
    """
    return _match_path(root_path, regexp, True)


def match_path_except(root_path, regexp):
    """Search from C{root_path} and yield filenames that don't match C{regexp}.

    Hidden directories are ignored.

    @param root_path: The root path to search from.
    @param regexp: A string containing a regular expression to match
        filenames against.
    """
    return _match_path(root_path, regexp, False)


def _match_path(root_path, regexp, include):
    hidden_directory = re.compile(".*/\..*")
    pattern = re.compile(regexp)
    for directory, subdirectories, filenames in os.walk(root_path):
        if not hidden_directory.match(directory):
            for filename in filenames:
                path = os.path.join(directory, filename)
                match = pattern.match(path)
                if match and include:
                    yield path
                elif not match and not include:
                    yield path
