# Copyright (c) 2007 Canonical
#
# Written by Jamshed Kakar <jkakar@kakar.ca>
#
# This file is part of AutoPPA.
#
# AutoPPA is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation; either version 2.1 of the
# License, or (at your option) any later version.
#
# AutoPPA is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import tempfile
import shutil


class FakeExpect(object):

    def __init__(self):
        self.commands = []
        self.include_working_directory = False

    def run(self, command, logfile=None, timeout=None):
        data = {"logfile": logfile, "timeout": timeout}
        if self.include_working_directory:
            data["working-directory"] = os.getcwd()
        self.commands.append(("run", command, data))

    def expect(self, pattern):
        self.commands.append(("expect", pattern))


class FilesystemPath(object):

    def __init__(self):
        self.dirname = tempfile.mkdtemp()
        self.counter = 0

    def tear_down(self):
        shutil.rmtree(self.dirname)

    def make_dir(self, path=None):
        path = os.path.join(self.dirname, path) or self.make_path()
        os.mkdir(path)
        return path

    def make_path(self, content=None, path=None):
        if path is None:
            self.counter += 1
            path = "%s/%03d" % (self.dirname, self.counter)
        else:
            path = os.path.join(self.dirname, path)
            directory = os.path.dirname(path)
            if directory != self.dirname and not os.path.isdir(directory):
                os.mkdir(directory)

        if content is not None:
            file = open(path, "w")
            try:
                file.write(content)
            finally:
                file.close()
        return path
