# Copyright (c) 2007 Canonical
#
# Written by Jamshed Kakar <jkakar@kakar.ca>
#
# This file is part of AutoPPA.
#
# AutoPPA is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation; either version 2.1 of the
# License, or (at your option) any later version.
#
# AutoPPA is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from autoppa.configuration import Configuration
from autoppa.testing import FilesystemPath


class ConfigurationTest(unittest.TestCase):

    def setUp(self):
        super(ConfigurationTest, self).setUp()
        self.fs = FilesystemPath()

    def tearDown(self):
        self.fs.tear_down()
        super(ConfigurationTest, self).tearDown()

    def test_from_file(self):
        """
        Factory method L{Configuration.from_file} creates a
        L{Configuration} instance from a configuration file.  The
        order of releases is maintained.
        """
        content = """\
[supertool]
email = John Smith <john@upside.com>
branch = /home/john/src/supertool/production
repository = /home/john/src/supertool
releases = dapper edgy gutsy feisty
"""
        path = self.fs.make_path(content=content)
        configuration = Configuration.from_file(path)
        data = configuration.get_build_target("supertool")
        self.assertEquals(data["email"], "John Smith <john@upside.com>")
        self.assertEquals(data["branch"], "/home/john/src/supertool/production")
        self.assertEquals(data["repository"], "/home/john/src/supertool")
        self.assertEquals(data["releases"], "dapper edgy gutsy feisty")

    def test_get_missing_build_target(self):
        """
        L{Configuration.get_build_target} returns C{None} if the
        specified build target is unknown.
        """
        content = """\
[supertool]
email = John Smith <john@upside.com>
branch = /home/john/src/supertool/production
repository = /home/john/src/supertool
releases = dapper edgy gutsy feisty
"""
        path = self.fs.make_path(content=content)
        configuration = Configuration.from_file(path)
        self.assertEquals(configuration.get_build_target("awesometool"), None)
